import React, { Component, Fragment } from 'react'

import { Panel, Tabs, Tab, Badge, Button } from 'react-bootstrap'

import { AccessControl } from '~/components/Shared/Utils'
import EditableInput from '../common/EditableInput'
import TransitionSection from './TransitionSection'

const style = require('./style.scss')

export default class SkillCallNodePropertiesPanel extends Component {
  renameNode = text => {
    if (text && text !== this.props.node.name) {
      this.props.updateNode({ name: text })
    }
  }

  transformText(text) {
    return text.replace(/[^a-z0-9-_\.]/gi, '_')
  }

  render() {
    const { node, readOnly } = this.props

    const editSkill = () => this.props.requestEditSkill(node.id)

    return (
      <div className={style.node}>
        <Panel>
          <EditableInput
            readOnly={readOnly}
            value={node.name}
            className={style.name}
            onChanged={this.renameNode}
            transform={this.transformText}
          />
          <div style={{ padding: '5px' }}>
            <AccessControl resource="bot.skills" operation="write">
              <Button onClick={editSkill}>Edit skill</Button>
            </AccessControl>
          </div>
        </Panel>
        <Tabs animation={false} id="node-props-modal-skill-node-tabs">
          <Tab
            eventKey="transitions"
            title={
              <Fragment>
                <Badge>{(node.next && node.next.length) || 0}</Badge> Transitions
              </Fragment>
            }
          >
            <TransitionSection
              readOnly={readOnly}
              items={node.next}
              currentFlow={this.props.flow}
              header="Transitions"
              subflows={this.props.subflows}
              onItemsUpdated={items => this.props.updateNode({ next: items })}
            />
          </Tab>
        </Tabs>
      </div>
    )
  }
}
